## pygame_chess_api package
[![Documentation Status](https://readthedocs.org/projects/pygame-chess-api/badge/?version=latest)](https://pygame-chess-api.readthedocs.io/en/latest/?badge=latest) [![wakatime](https://wakatime.com/badge/user/4934267d-01b8-4a77-9322-a854826595a9/project/25d5089e-cfbb-4988-bf34-b5d5d6667274.svg)](https://wakatime.com/badge/user/4934267d-01b8-4a77-9322-a854826595a9/project/25d5089e-cfbb-4988-bf34-b5d5d6667274)

Welcome to pygame_chess_api!
==================================

The goal of this package is to be able to **easily setup chess games**, with the **game engine and the graphical user interface given**.
Especially to enable you to *quickly build chess AI*.


Installation
=========================
To install this package you only have to run this: `pip install pygame_chess_api`.

If you're having issues with the installation, please try to install pygame manually first with `pip install pygame` and then try again to install this package without dependencies with the following command: `pip install --no-deps pygame_chess_api`.

If it doesn't work, feel free to open an issue

Getting Started
========================
To get started you can check the *Quickstart* on the documentation (https://pygame-chess-api.readthedocs.io/)

To run a quick test and see what working witch pygame_chess_api can look like you can also download examples on the GitHub Repository

**Please check the Documentation at https://pygame-chess-api.readthedocs.io/ to access to Quickstart, References, etc**